Overview of Orbitant
====================

..  start-badges

|buildstatus| |docs|

.. |buildstatus| image:: https://img.shields.io/travis/metrasynth/orbitant.svg?style=flat
    :alt: build status
    :scale: 100%
    :target: https://travis-ci.org/metrasynth/orbitant

.. |docs| image:: https://readthedocs.org/projects/orbitant/badge/?version=latest
    :alt: Documentation Status
    :scale: 100%
    :target: https://orbitant.readthedocs.io/en/latest/?badge=latest

..  end-badges

Part of the Metrasynth_ project.

.. _Metrasynth: https://metrasynth.github.io/


Purpose
-------

MIDI clock and musical timing utilities for Python.


Status
------

..  warning::

    This package is very experimental. Features and APIs may change a great
    deal before being considered stable.


Requirements
------------

macOS::

    $ brew install rtmidi
